The schemas defined in this directory follow the very simple format provided in
hyperledger. Future iterations should utilize the rich schemas as described in
[RFC 0250: Rich Schema Objects](https://github.com/hyperledger/aries-rfcs/tree/master/concepts/0250-rich-schemas).
